@@ -3,7 +3,7 @@ import matplotlib.pyplot as plt
 import scipy.stats
 from . import matcher
 from scipy.stats import t
-import scipy
+from scipy.sparse import issparse
 import math
 import pandas as pd
 
@@ -189,14 +189,14 @@ def BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName, verbo
     dimensionality = cluster1.shape[1]
     print("weird")
 
-    if scipy.sparse.issparse(cluster1.X):
+    if issparse(cluster1.X):
         print("C1 is sparse")
         C1Mean = cluster1.X.mean(axis=0)
     else:
         print("C1 is dense")
         C1Mean = np.mean(cluster1.X, axis=0, keepdims=True)
 
-    if scipy.sparse.issparse(cluster2.X):
+    if issparse(cluster2.X):
         print("C2 is sparse")
         C2Mean = cluster2.X.mean(axis=0)
     else:
